# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import vat
import io
from vat.gb import moss

def test_empty_moss():
    """Test generating an empty MOSS return."""
    with io.BytesIO() as f:
        moss.generate(f)
        assert f.getvalue() != b''

def test_uk_moss():
    """Test generating a UK-only MOSS return."""
    with io.BytesIO() as f:
        moss.generate(f, uk_supplies = [
            ('FR', moss.STANDARD_RATE, 12.34, 123.45, 8.88),
            ('DE', moss.REDUCED_RATE, 56.78, 12345.678, 99.9)
            ])

        assert f.getvalue() != b''

def test_fe_moss():
    """Test generating a foreign establishment MOSS return."""
    with io.BytesIO() as f:
        moss.generate(f, fe_supplies = [
            ('DE1234567', 'FR', moss.STANDARD_RATE, 12.345, 678.901, 23.45)
            ])

        assert f.getvalue() != b''

def test_uk_fe_moss():
    """Test generating a UK & FE MOSS return."""
    with io.BytesIO() as f:
        moss.generate(f, uk_supplies = [
            ('FR', moss.STANDARD_RATE, 12.34, 123.45, 8.88),
            ('DE', moss.REDUCED_RATE, 56.78, 12345.678, 99.9)
            ],
            fe_supplies = [
            ('DE1234567', 'FR', moss.STANDARD_RATE, 12.345, 678.901, 23.45)
            ])

        assert f.getvalue() != b''



from xml.sax import saxutils

B2B_GOODS = 0
B2B_INTERMEDIARY = 2
B2B_SERVICES = 3

def generate(file_obj,
             vat_number, branch, year, period, contact, lines):
    """Generate an HMRC XML ECSL document.

       :param file_obj: A file-like object to which the ECSL should be written.
       :param str vat_number: The numeric part of your UK VAT number.
       :param int branch: The branch number (set to 0 if you don't know
         otherwise).
       :param int year: The year.
       :param int period: The month within the year (if quarterly, it should be
         the month at the end of the current quarter).
       :param str contact: The name of the contact for HMRC.
       :param lines: An iterable yielding (country, VAT number, value, type)
         tuples.  The country is a two-character EU VAT country code; the VAT
         number must be unadorned and numeric; the value should be an integer in
         Sterling, and may be negative.  The type field should be one of

           :py:const:`B2B_GOODS`
           :py:const:`B2B_INTERMEDIARY`
           :py:const:`B2B_SERVICES`
        """

    file_obj.write(("""<?xml version="1.0" encoding="UTF-8"?>
<Submission type='HMRC_VAT_ESL_BULK_SUBMISSION_FILE'>
  <TraderVRN>%(vat_number)s</TraderVRN>
  <Branch>%(branch)03d</Branch>
  <Year>%(year)04d</Year>
  <Period>%(period)02d</Period>
  <CurrencyA3>GBP</CurrencyA3>
  <ContactName>%(contact)s</ContactName>
  <Online>0</Online>
  <SubmissionLines>
""" % { 'vat_number': vat_number,
        'branch': branch,
        'year': year,
        'period': period,
        'contact': saxutils.escape(contact) }).encode('utf-8'))

    for country, vat_number, value, kind in lines:
        file_obj.write(("""    <SubmissionLine>
      <CountryA2>%(country)s</CountryA2>
      <CustomerVRN>%(vat_number)s</CustomerVRN>
      <Value>%(value)d</Value>
      <Indicator>%(kind)d</Indicator>
    </SubmissionLine>
""" % { 'country': country,
        'vat_number': vat_number,
        'value': value,
        'kind': kind }).encode('utf-8'))

    file_obj.write(b"""  </SubmissionLines>
</Submission>
""")



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import io

from vat.gb import ecsl

def test_empty_ecsl():
    """Test generation of an empty EC sales list."""
    output = io.BytesIO()

    ecsl.generate(output, '123456789', 0, 2014, 3, 'A N Other', [])

    assert output.getvalue() == b"""<?xml version="1.0" encoding="UTF-8"?>
<Submission type='HMRC_VAT_ESL_BULK_SUBMISSION_FILE'>
  <TraderVRN>123456789</TraderVRN>
  <Branch>000</Branch>
  <Year>2014</Year>
  <Period>03</Period>
  <CurrencyA3>GBP</CurrencyA3>
  <ContactName>A N Other</ContactName>
  <Online>0</Online>
  <SubmissionLines>
  </SubmissionLines>
</Submission>
"""

def test_simple_ecsl():
    """Test generation of a simple EC sales list."""
    output = io.BytesIO()

    ecsl.generate(output, '123456789', 0, 2014, 3, 'A N Other',
                  [ ('HU', '12345678', 19, ecsl.B2B_SERVICES),
                    ('NL', '87654321B01', -28, ecsl.B2B_GOODS),
                    ('PT', '123456789', 44, ecsl.B2B_INTERMEDIARY) ])

    assert output.getvalue() == b"""<?xml version="1.0" encoding="UTF-8"?>
<Submission type='HMRC_VAT_ESL_BULK_SUBMISSION_FILE'>
  <TraderVRN>123456789</TraderVRN>
  <Branch>000</Branch>
  <Year>2014</Year>
  <Period>03</Period>
  <CurrencyA3>GBP</CurrencyA3>
  <ContactName>A N Other</ContactName>
  <Online>0</Online>
  <SubmissionLines>
    <SubmissionLine>
      <CountryA2>HU</CountryA2>
      <CustomerVRN>12345678</CustomerVRN>
      <Value>19</Value>
      <Indicator>3</Indicator>
    </SubmissionLine>
    <SubmissionLine>
      <CountryA2>NL</CountryA2>
      <CustomerVRN>87654321B01</CustomerVRN>
      <Value>-28</Value>
      <Indicator>0</Indicator>
    </SubmissionLine>
    <SubmissionLine>
      <CountryA2>PT</CountryA2>
      <CustomerVRN>123456789</CustomerVRN>
      <Value>44</Value>
      <Indicator>2</Indicator>
    </SubmissionLine>
  </SubmissionLines>
</Submission>
"""

def test_utf8_ecsl():
    """Test that we can use unusual characters in the contact name."""

    output = io.BytesIO()

    ecsl.generate(output, '123456789', 0, 2014, 3, 'Ж؈ဆあ & <>', [])

    assert output.getvalue().decode('utf-8') == \
"""<?xml version="1.0" encoding="UTF-8"?>
<Submission type='HMRC_VAT_ESL_BULK_SUBMISSION_FILE'>
  <TraderVRN>123456789</TraderVRN>
  <Branch>000</Branch>
  <Year>2014</Year>
  <Period>03</Period>
  <CurrencyA3>GBP</CurrencyA3>
  <ContactName>Ж؈ဆあ &amp; &lt;&gt;</ContactName>
  <Online>0</Online>
  <SubmissionLines>
  </SubmissionLines>
</Submission>
"""



from .memberstate import member_states, MemberState, Threshold
from .vat_check import check_details
from .vies import VIESException, VIESSOAPException, VIESHTTPException, \
     VIESResponseBase, VIESResponse, VIESApproxResponse

__all__ = ['member_states', 'MemberState', 'Threshold', 'check_details',
           'VIESException', 'VIESSOAPException', 'VIESHTTPException',
           'VIESResponseBase', 'VIESResponse', 'VIESApproxResponse']



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import unittest

from vat.metaphone.metaphone import doublemetaphone


class MetaphoneTestCase(unittest.TestCase):
    """
    """
    def test_single_result(self):
        result = doublemetaphone(u"aubrey")
        self.assertEquals(result, ('APR', ''))

    def test_double_result(self):
        result = doublemetaphone(u"richard")
        self.assertEquals(result, ('RXRT', 'RKRT'))

    def test_general_word_list(self):
        result = doublemetaphone('Jose')
        self.assertEquals(result, ('JS', 'HS'))
        result = doublemetaphone('cambrillo')
        self.assertEquals(result, ('KMPRL', 'KMPR'))
        result = doublemetaphone('otto')
        self.assertEquals(result, ('AT', ''))
        result = doublemetaphone('aubrey')
        self.assertEquals(result, ('APR', ''))
        result = doublemetaphone('maurice')
        self.assertEquals(result, ('MRS', ''))
        result = doublemetaphone('auto')
        self.assertEquals(result, ('AT', ''))
        result = doublemetaphone('maisey')
        self.assertEquals(result, ('MS', ''))
        result = doublemetaphone('catherine')
        self.assertEquals(result, ('K0RN', 'KTRN'))
        result = doublemetaphone('geoff')
        self.assertEquals(result, ('JF', 'KF'))
        result = doublemetaphone('Chile')
        self.assertEquals(result, ('XL', ''))
        result = doublemetaphone('katherine')
        self.assertEquals(result, ('K0RN', 'KTRN'))
        result = doublemetaphone('steven')
        self.assertEquals(result, ('STFN', ''))
        result = doublemetaphone('zhang')
        self.assertEquals(result, ('JNK', ''))
        result = doublemetaphone('bob')
        self.assertEquals(result, ('PP', ''))
        result = doublemetaphone('ray')
        self.assertEquals(result, ('R', ''))
        result = doublemetaphone('Tux')
        self.assertEquals(result, ('TKS', ''))
        result = doublemetaphone('bryan')
        self.assertEquals(result, ('PRN', ''))
        result = doublemetaphone('bryce')
        self.assertEquals(result, ('PRS', ''))
        result = doublemetaphone('Rapelje')
        self.assertEquals(result, ('RPL', ''))
        result = doublemetaphone('richard')
        self.assertEquals(result, ('RXRT', 'RKRT'))
        result = doublemetaphone('solilijs')
        self.assertEquals(result, ('SLLS', ''))
        result = doublemetaphone('Dallas')
        self.assertEquals(result, ('TLS', ''))
        result = doublemetaphone('Schwein')
        self.assertEquals(result, ('XN', 'XFN'))
        result = doublemetaphone('dave')
        self.assertEquals(result, ('TF', ''))
        result = doublemetaphone('eric')
        self.assertEquals(result, ('ARK', ''))
        result = doublemetaphone('Parachute')
        self.assertEquals(result, ('PRKT', ''))
        result = doublemetaphone('brian')
        self.assertEquals(result, ('PRN', ''))
        result = doublemetaphone('randy')
        self.assertEquals(result, ('RNT', ''))
        result = doublemetaphone('Through')
        self.assertEquals(result, ('0R', 'TR'))
        result = doublemetaphone('Nowhere')
        self.assertEquals(result, ('NR', ''))
        result = doublemetaphone('heidi')
        self.assertEquals(result, ('HT', ''))
        result = doublemetaphone('Arnow')
        self.assertEquals(result, ('ARN', 'ARNF'))
        result = doublemetaphone('Thumbail')
        self.assertEquals(result, ('0MPL', 'TMPL'))

    def test_homophones(self):
        self.assertEqual(
            doublemetaphone(u"tolled"),
            doublemetaphone(u"told"))
        self.assertEqual(
            doublemetaphone(u"katherine"),
            doublemetaphone(u"catherine"))
        self.assertEqual(
            doublemetaphone(u"brian"),
            doublemetaphone(u"bryan"))

    def test_similar_names(self):
        result = doublemetaphone("Bartoš")
        self.assertEquals(result, ('PRTS', ''))
        result = doublemetaphone(u"Bartosz")
        self.assertEquals(result, ('PRTS', 'PRTX'))
        result = doublemetaphone(u"Bartosch")
        self.assertEquals(result, ('PRTX', ''))
        result = doublemetaphone(u"Bartos")
        self.assertEquals(result, ('PRTS', ''))

        result = set(doublemetaphone(u"Jablonski")).intersection(
            doublemetaphone(u"Yablonsky"))
        self.assertEquals(list(result), ['APLNSK'])
        result = set(doublemetaphone(u"Smith")).intersection(
            doublemetaphone(u"Schmidt"))
        self.assertEquals(list(result), ['XMT'])

    def test_non_english_unicode(self):
        result = doublemetaphone("andestādītu")
        self.assertEquals(result, ('ANTSTTT', ''))

    def test_c_cedilla(self):
        result = doublemetaphone("français")
        self.assertEquals(result, ('FRNS', 'FRNSS'))
        result = doublemetaphone("garçon")
        self.assertEquals(result, ('KRSN', ''))
        result = doublemetaphone("leçon")
        self.assertEquals(result, ('LSN', ''))

    def test_various_german(self):
        result = doublemetaphone("ach")
        self.assertEquals(result, ("AX", "AK"))
        result = doublemetaphone("bacher")
        self.assertEquals(result, ("PKR", ""))
        result = doublemetaphone("macher")
        self.assertEquals(result, ("MKR", ""))

    def test_various_italian(self):
        result = doublemetaphone("bacci")
        self.assertEquals(result, ("PX", ""))
        result = doublemetaphone("bertucci")
        self.assertEquals(result, ("PRTX", ""))
        result = doublemetaphone("bellocchio")
        self.assertEquals(result, ("PLX", ""))
        result = doublemetaphone("bacchus")
        self.assertEquals(result, ("PKS", ""))
        result = doublemetaphone("focaccia")
        self.assertEquals(result, ("FKX", ""))
        result = doublemetaphone("chianti")
        self.assertEquals(result, ("KNT", ""))
        result = doublemetaphone("tagliaro")
        self.assertEquals(result, ("TKLR", "TLR"))
        result = doublemetaphone("biaggi")
        self.assertEquals(result, ("PJ", "PK"))

    def test_various_spanish(self):
        result = doublemetaphone("bajador")
        self.assertEquals(result, ("PJTR", "PHTR"))
        result = doublemetaphone("cabrillo")
        self.assertEquals(result, ("KPRL", "KPR"))
        result = doublemetaphone("gallegos")
        self.assertEquals(result, ("KLKS", "KKS"))
        result = doublemetaphone("San Jacinto")
        self.assertEquals(result, ("SNHSNT", ""))

    def test_various_french(self):
        result = doublemetaphone("rogier")
        self.assertEquals(result, ("RJ", "RKR"))
        result = doublemetaphone("breaux")
        self.assertEquals(result, ("PR", ""))

    def test_various_slavic(self):
        result = doublemetaphone("Wewski")
        self.assertEquals(result, ("ASK", "FFSK"))

    def test_various_chinese(self):
        result = doublemetaphone("zhao")
        self.assertEquals(result, ("J", ""))

    def test_dutch_origin(self):
        result = doublemetaphone("school")
        self.assertEquals(result, ("SKL", ""))
        result = doublemetaphone("schooner")
        self.assertEquals(result, ("SKNR", ""))
        result = doublemetaphone("schermerhorn")
        self.assertEquals(result, ("XRMRRN", "SKRMRRN"))
        result = doublemetaphone("schenker")
        self.assertEquals(result, ("XNKR", "SKNKR"))

    def test_ch_words(self):
        result = doublemetaphone("Charac")
        self.assertEquals(result, ("KRK", ""))
        result = doublemetaphone("Charis")
        self.assertEquals(result, ("KRS", ""))
        result = doublemetaphone("chord")
        self.assertEquals(result, ("KRT", ""))
        result = doublemetaphone("Chym")
        self.assertEquals(result, ("KM", ""))
        result = doublemetaphone("Chia")
        self.assertEquals(result, ("K", ""))
        result = doublemetaphone("chem")
        self.assertEquals(result, ("KM", ""))
        result = doublemetaphone("chore")
        self.assertEquals(result, ("XR", ""))
        result = doublemetaphone("orchestra")
        self.assertEquals(result, ("ARKSTR", ""))
        result = doublemetaphone("architect")
        self.assertEquals(result, ("ARKTKT", ""))
        result = doublemetaphone("orchid")
        self.assertEquals(result, ("ARKT", ""))

    def test_cc_words(self):
        result = doublemetaphone("accident")
        self.assertEquals(result, ("AKSTNT", ""))
        result = doublemetaphone("accede")
        self.assertEquals(result, ("AKST", ""))
        result = doublemetaphone("succeed")
        self.assertEquals(result, ("SKST", ""))

    def test_mc_words(self):
        result = doublemetaphone("mac caffrey")
        self.assertEquals(result, ("MKFR", ""))
        result = doublemetaphone("mac gregor")
        self.assertEquals(result, ("MKRKR", ""))
        result = doublemetaphone("mc crae")
        self.assertEquals(result, ("MKR", ""))
        result = doublemetaphone("mcclain")
        self.assertEquals(result, ("MKLN", ""))

    def test_gh_words(self):
        result = doublemetaphone("laugh")
        self.assertEquals(result, ("LF", ""))
        result = doublemetaphone("cough")
        self.assertEquals(result, ("KF", ""))
        result = doublemetaphone("rough")
        self.assertEquals(result, ("RF", ""))

    def test_g3_words(self):
        result = doublemetaphone("gya")
        self.assertEquals(result, ("K", "J"))
        result = doublemetaphone("ges")
        self.assertEquals(result, ("KS", "JS"))
        result = doublemetaphone("gep")
        self.assertEquals(result, ("KP", "JP"))
        result = doublemetaphone("geb")
        self.assertEquals(result, ("KP", "JP"))
        result = doublemetaphone("gel")
        self.assertEquals(result, ("KL", "JL"))
        result = doublemetaphone("gey")
        self.assertEquals(result, ("K", "J"))
        result = doublemetaphone("gib")
        self.assertEquals(result, ("KP", "JP"))
        result = doublemetaphone("gil")
        self.assertEquals(result, ("KL", "JL"))
        result = doublemetaphone("gin")
        self.assertEquals(result, ("KN", "JN"))
        result = doublemetaphone("gie")
        self.assertEquals(result, ("K", "J"))
        result = doublemetaphone("gei")
        self.assertEquals(result, ("K", "J"))
        result = doublemetaphone("ger")
        self.assertEquals(result, ("KR", "JR"))
        result = doublemetaphone("danger")
        self.assertEquals(result, ("TNJR", "TNKR"))
        result = doublemetaphone("manager")
        self.assertEquals(result, ("MNKR", "MNJR"))
        result = doublemetaphone("dowager")
        self.assertEquals(result, ("TKR", "TJR"))

    def test_pb_words(self):
        result = doublemetaphone("Campbell")
        self.assertEquals(result, ("KMPL", ""))
        result = doublemetaphone("raspberry")
        self.assertEquals(result, ("RSPR", ""))

    def test_th_words(self):
        result = doublemetaphone("Thomas")
        self.assertEquals(result, ("TMS", ""))
        result = doublemetaphone("Thames")
        self.assertEquals(result, ("TMS", ""))



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import decimal
from decimal import Decimal as d
import datetime
import re

_alpha_2_map = {}
_code_map = {}

class Threshold(object):
    def __init__(self, currency, amount):
        self.currency = currency
        self.amount = amount

class MemberState(object):
    """Represents and holds information about an EU member state."""
    def __init__(self, code, iso_alpha_2, name,
                 standard_rate, reduced_rates,
                 super_reduced_rate, parking_rate,
                 currency,
                 special_scheme_threshold,
                 distance_selling_threshold,
                 small_enterprise_threshold,
                 number_format):
        def to_rate(x):
            if x is None:
                return None
            return decimal.Decimal('%.1f' % x) / 100
        def to_rates(x):
            if x is None:
                return None
            if not isinstance(x, (tuple, list)):
                return to_rates((x, ))
            result = []
            for y in x:
                result.append(to_rate(y))
            return tuple(result)
        def to_threshold(x):
            if x is None:
                return None
            if isinstance(x, (tuple, list)):
                result = []
                for y in x:
                    currency, amount = y.split(' ')
                    result.append(Threshold(currency, decimal.Decimal(amount)))
                return tuple(result)
            currency, amount = x.split(' ')
            return Threshold(currency, decimal.Decimal(amount))

        # The VAT country code (e.g. Greece is 'EL')
        self.code = code

        # The ISO 3166 alpha-2 code (e.g. Greece is 'GR')
        self.iso_alpha_2 = iso_alpha_2

        # The name of this Member State (in English)
        self.name = name

        # The standard VAT rate (e.g. 20% = 0.2)
        self.standard_rate = to_rate(standard_rate)

        # The reduced VAT rates (a tuple, or None)
        self.reduced_rates = to_rates(reduced_rates)

        # The super reduced rate (or None)
        self.super_reduced_rate = to_rate(super_reduced_rate)

        # The "parking" rate (or None)
        self.parking_rate = to_rate(parking_rate)

        # A regular expression (as a string) matching the VAT number format
        self.number_regex = '^(%s)$' % number_format
        
        # A re.RegexObject matching the VAT number format
        self.number_format = re.compile(self.number_regex)

        # The currency used in this Member State
        self.currency = currency

        # The special scheme threshold (a Threshold object)
        self.special_scheme_threshold = to_threshold(special_scheme_threshold)

        # The distance selling threshold (a Threshold object)
        self.distance_selling_threshold = to_threshold(distance_selling_threshold)

        # The small enterprise threshold (a Threshold object)
        self.small_enterprise_threshold = to_threshold(small_enterprise_threshold)
        
        _alpha_2_map[iso_alpha_2] = self
        _code_map[code] = self
        
    @staticmethod
    def by_code(code):
        return _code_map[code]

    @staticmethod
    def by_iso_alpha_2(alpha_2):
        return _alpha_2_map[alpha_2]
    
MS = MemberState

### Make your window *REALLY WIDE* before editing below.

# Sources:
# http://ec.europa.eu/taxation_customs/resources/documents/taxation/vat/how_vat_works/rates/vat_rates_en.pdf
# http://ec.europa.eu/taxation_customs/resources/documents/taxation/vat/traders/vat_community/vat_in_ec_annexi.pdf

# 2015-01-01: There have been changes to the thresholds since the above Annex I document was last updated.
#             Notably, Lithuania is now part of the Euro zone, so I've updated its entry in the table to
#             reflect that change.  Unfortunately, there does not appear to be any obvious source of
#             information on the thresholds that now apply (since LTL is no longer in use); I've rounded
#             to the nearest round Euro amount for now.

# Update these dates when you update the table below; they should reflect the dates of the update, not any dates
# you might see on the documents above.
vat_rate_update_date = datetime.date(2015, 1, 1)
threshold_update_date = datetime.date(2015, 1, 1)

# ********************************************************************************************************************
# *                                                                                                                  *
# *   N.B. It is your responsibility to choose the correct rate, which might vary depending on what you're selling.  *
# *        It is also your responsibility to choose the correct threshold.                                           *
# *                                                                                                                  *
# *        The maintainer of this package takes NO RESPONSIBILITY for any typos or inaccuracies contained below, or  *
# *        for any mistakes you might make using the data contained herein.                                          *
# *                                                                                                                  *
# ********************************************************************************************************************

# All member states, along with their VAT information.  Note that some countries have multiple small VAT thresholds; note also Hungary, which quotes
# its special and distance thresholds in Euros even though it uses the Forint.
member_states = [
    #  code  iso   name               rates                                    currency  thresholds                                            number format
    #                                 standard  reduced        super  parking                   special          distance             small
    MS('BE', 'BE', 'Belgium',         21.0,     (12.0,  6.0),  None,  12.0,    'EUR',     'EUR 11200.00',   'EUR 35000.00',   'EUR 15000.00',  r'\d{10}'),
    MS('BG', 'BG', 'Bulgaria',        20.0,             9.0,   None,  None,    'BGN',     'BGN 20000.00',   'BGN 70000.00',   'BGN 50000.00',  r'\d{9,10}'),
    MS('CZ', 'CZ', 'Czech Republic',  21.0,            15.0,   None,  None,    'CZK',    'CZK 326000.00', 'CZK 1140000.00', 'CZK 1000000.00',  r'\d{8,10}'),
    MS('DK', 'DK', 'Denmark',         25.0,            None,   None,  None,    'DKK',     'DKK 80000.00',  'DKK 280000.00',   'DKK 50000.00',  r'(?:\d{2}\s*){3}\d{2}'),
    MS('DE', 'DE', 'Germany',         19.0,             7.0,   None,  None,    'EUR',     'EUR 12500.00',  'EUR 100000.00',   'EUR 17500.00',  r'\d{9}'),
    MS('EE', 'EE', 'Estonia',         20.0,             9.0,   None,  None,    'EUR',     'EUR 10000.00',   'EUR 35000.00',   'EUR 16000.00',  r'\d{9}'),
    MS('EL', 'GR', 'Greece',          23.0,     (13.0,  6.5),  None,  None,    'EUR',     'EUR 10000.00',   'EUR 35000.00',   ('EUR 5000.00',
                                                                                                                              'EUR 10000.00'), r'\d{9}'),
    MS('ES', 'ES', 'Spain',           21.0,            10.0,    4.0,  None,    'EUR',     'EUR 10000.00',   'EUR 35000.00',            None,   r'[A-Z\d]\d{7}[A-Z\d]'),
    MS('FR', 'FR', 'France',          20.0,     (10.0,  5.5),   2.1,  None,    'EUR',     'EUR 10000.00',  'EUR 100000.00',  ('EUR 34900.00',
                                                                                                                              'EUR 90300.00'), r'[A-Z\d]{2}\s*\d{9}'),
    MS('HR', 'HR', 'Croatia',         25.0,     (13.0,  5.0),  None,  None,    'HRK',     'HRK 77000.00',  'HRK 270000.00',  'HRK 230000.00',  r'\d{11}'),
    MS('IE', 'IE', 'Ireland',         23.0,     (13.5,  9.0),   4.8,  13.5,    'EUR',     'EUR 41000.00',   'EUR 35000.00',  ('EUR 37500.00',
                                                                                                                              'EUR 75000.00'), r'\d[A-Z\d+*]\d{5}[A-Z]{1,2}'),
    MS('IT', 'IT', 'Italy',           22.0,            10.0,    4.0,  None,    'EUR',     'EUR 10000.00',   'EUR 35000.00',   'EUR 30000.00',  r'\d{11}'),
    MS('CY', 'CY', 'Cyprus',          19.0,      (9.0,  5.0),  None,  None,    'EUR',     'EUR 10251.00',   'EUR 35000.00',   'EUR 15600.00',  r'\d{8}[A-Z]'),
    MS('LV', 'LV', 'Latvia',          21.0,            12.0,   None,  None,    'EUR',     'EUR 10000.00',   'EUR 35000.00',   'EUR 50000.00',  r'\d{11}'),
    MS('LT', 'LT', 'Lithuania',       21.0,      (9.0,  5.0),  None,  None,    'EUR',     'EUR 10000.00',   'EUR 35000.00',   'EUR 45000.00',  r'\d{9}(?:\d{3})?'),
    MS('LU', 'LU', 'Luxembourg',      15.0,     (12.0,  6.0),   3.0,  12.0,    'EUR',     'EUR 10000.00',  'EUR 100000.00',   'EUR 25000.00',  r'\d{8}'),
    MS('HU', 'HU', 'Hungary',         27.0,     (18.0,  5.0),  None,  None,    'HUF',     'EUR 35000.00',   'EUR 35000.00', 'HUF 6000000.00',  r'\d{8}'),
    MS('MT', 'MT', 'Malta',           18.0,      (7.0,  5.0),  None,  None,    'EUR',     'EUR 10000.00',   'EUR 35000.00',  ('EUR 14000.00',
                                                                                                                              'EUR 24000.00',
                                                                                                                              'EUR 35000.00'), r'\d{8}'),
    MS('NL', 'NL', 'Netherlands',     21.0,             6.0,   None,  None,    'EUR',     'EUR 10000.00',  'EUR 100000.00',            None,   r'\d{9}B\d{2}'),
    MS('AT', 'AT', 'Austria',         20.0,            10.0,   None,  12.0,    'EUR',     'EUR 11000.00',   'EUR 35000.00',   'EUR 30000.00',  r'U\d{8}'),
    MS('PL', 'PL', 'Poland',          23.0,      (8.0,  5.0),  None,  None,    'PLN',     'PLN 50000.00',  'PLN 160000.00',  'PLN 150000.00',  r'\d{10}'),
    MS('PT', 'PT', 'Portugal',        23.0,     (13.0,  6.0),  None,  13.0,    'EUR',     'EUR 10000.00',   'EUR 35000.00',  ('EUR 10000.00',
                                                                                                                              'EUR 12500.00'), r'\d{9}'),
    MS('RO', 'RO', 'Romania',         24.0,      (9.0,  5.0),  None,  None,    'RON',     'RON 34000.00',  'RON 118000.00',  'RON 220000.00',  r'\d{2,10}'),
    MS('SI', 'SI', 'Slovenia',        22.0,             9.5,   None,  None,    'EUR',     'EUR 10000.00',   'EUR 35000.00',   'EUR 50000.00',  r'\d{8}'),
    MS('SK', 'SK', 'Slovakia',        20.0,            10.0,   None,  None,    'EUR',     'EUR 13941.00',   'EUR 35000.00',   'EUR 49790.00',  r'\d{10}'),
    MS('FI', 'FI', 'Finland',         24.0,     (14.0, 10.0),  None,  None,    'EUR',     'EUR 10000.00',   'EUR 35000.00',    'EUR 8500.00',  r'\d{8}'),
    MS('SE', 'SE', 'Sweden',          25.0,     (12.0,  6.0),  None,  None,    'SEK',     'SEK 90000.00',  'SEK 320000.00',            None,   r'\d{12}'),
    MS('GB', 'GB', 'United Kingdom',  20.0,             5.0,   None,  None,    'GBP',     'GBP 81000.00',   'GBP 70000.00',   'GBP 81000.00',  r'\d{3}\s*\d{4}\s*\d{2}(?:\s*\d{3})?|GD\d{3}|HA\d{3}'),
    ]
    



# -*- coding: utf-8 -*-
import sys
from setuptools import setup, find_packages
from setuptools.command.test import test as TestCommand

class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        import pytest
        errno = pytest.main(self.test_args)
        sys.exit(errno)

with open('README.rst', 'rb') as f:
    long_desc = f.read().decode('utf-8')
        
setup(
    name='vat',
    version='0.2.0',
    description='A python package for dealing with VAT',
    long_description=long_desc,
    author='Alastair Houghton',
    author_email='alastair@alastairs-place.net',
    url='http://bitbucket.org/al45tair/vat',
    license='MIT License',
    packages=find_packages(),
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Topic :: Office/Business :: Financial',
        ],
    package_data = {
        'vat': ['gb/moss/resources/*']
        },
    tests_require=['pytest'],
    cmdclass={
        'test': PyTest
        },
    install_requires=[
        'six',
        'lxml >= 3.4.0',
        'python-dateutil >= 1.5',
        'python-Levenshtein >= 0.11.2',
        ],
    provides=['vat']
    )
